@@ -20,7 +20,15 @@ class MacroExtension(markdown.Extension):
     """ Macro plugin markdown extension for django-wiki. """
 
     def extendMarkdown(self, md):
-        md.inlinePatterns.add("dw-macros", MacroPattern(MACRO_RE, md), ">link")
+
+        i = md.inlinePatterns.get_index_for_name("link")
+        before = md.inlinePatterns._priority[i].priority
+        if i < len(md.inlinePatterns) - 1:
+            after = md.inlinePatterns._priority[i + 1].priority
+        else:
+            after = before - 10
+        priority = before - ((before - after) / 2)
+        md.inlinePatterns.register(MacroPattern(MACRO_RE, md), "dw-macros", priority)
 
 
 class MacroPattern(markdown.inlinepatterns.Pattern):
