@@ -2,7 +2,8 @@ from django.urls import re_path
 from wiki.core.plugins import registry
 from wiki.core.plugins.base import BasePlugin
 
-from . import settings, views
+from . import settings
+from . import views
 
 
 class NotifyPlugin(BasePlugin):
